@@ -28,6 +28,7 @@
  */
 
 /* revision history:
+ * gimp   1.3.26c;  2004/03/09  hof: bugfix (gimp_destroy_params)
  * gimp   1.3.20b;  2003/09/20  hof: gap_db_browser_dialog new param image_id
  * gimp   1.3.12a;  2003/05/02  hof: merge into CVS-gimp-gap project
  * gimp   1.3.8a;   2002/09/21  hof: gap_lastvaldesc
@@ -71,6 +72,7 @@
 #include "gap_dbbrowser_utils.h"
 #include "gap_lib.h"
 
+#define GAP_DB_BROWSER_FILTERALL_HELP_ID  "gap-filterall-db-browser"
 
 /* ------------------------
  * global gap DEBUG switch
@@ -84,28 +86,7 @@ extern int gap_debug;
 
 void p_gdisplays_update_full(gint32 image_id)
 {
-  GimpParam* l_params;
-  gint   l_retvals;
-
-  if(gap_filt_pdb_procedure_available("gimp_image_update_full", GAP_PTYP_ANY) >= 0)
-  {
-
-    l_params = gimp_run_procedure ("gimp_image_update_full",
-			         &l_retvals,
-			         GIMP_PDB_IMAGE,  image_id,
-			         GIMP_PDB_END);
-
-     /* Note: gimp_displays_update_full is not available in the official release gimp 0.99.16
-      *       (dont care if procedure is not there,
-      *        --> the user may not see the current layer, because
-      *            gimp_displays_flush() does not update on changes
-      *            of the visibility.
-      */
-
-     g_free(l_params);
-   }
    gimp_displays_flush();
-
 }
 
 /* pitstop dialog
@@ -507,7 +488,7 @@ int p_foreach_multilayer(GimpRunMode run_mode, gint32 image_id,
                l_rc = -1;
              }
 
-             g_free(l_params);
+             gimp_destroy_params(l_params, l_retvals);
           }
 
           if(l_rc < 0) break;
@@ -556,12 +537,10 @@ int p_foreach_multilayer(GimpRunMode run_mode, gint32 image_id,
  * ============================================================================
  */
 
-gint gap_proc_anim_apply(GimpRunMode run_mode, gint32 image_id, char *plugin_name)
+gint gap_proc_anim_apply(GimpRunMode run_mode, gint32 image_id, char *plugin_name
+  , GapFiltPdbApplyMode apply_mode)
 {
   GapDbBrowserResult  l_browser_result;
-  GapFiltPdbApplyMode            l_apply_mode;
-
-  l_apply_mode = GAP_PAPP_CONSTANT;
 
   if(run_mode == GIMP_RUN_INTERACTIVE)
   {
@@ -573,7 +552,8 @@ gint gap_proc_anim_apply(GimpRunMode run_mode, gint32 image_id, char *plugin_nam
                                  gap_filt_pdb_constraint_proc_sel1,
                                  gap_filt_pdb_constraint_proc_sel2,
                                  &l_browser_result,
-				 image_id)
+				 image_id,
+				 GAP_DB_BROWSER_FILTERALL_HELP_ID)
       < 0)
     {
       if(gap_debug) fprintf(stderr, "DEBUG: gap_db_browser_dialog cancelled\n");
@@ -581,7 +561,7 @@ gint gap_proc_anim_apply(GimpRunMode run_mode, gint32 image_id, char *plugin_nam
     }
 
     strcpy(plugin_name, l_browser_result.selected_proc_name);
-    if(l_browser_result.button_nr == 1) l_apply_mode = GAP_PAPP_VARYING_LINEAR;
+    if(l_browser_result.button_nr == 1) apply_mode = GAP_PAPP_VARYING_LINEAR;
 
     if(gap_debug) fprintf(stderr, "DEBUG: gap_db_browser_dialog SELECTED:%s\n", plugin_name);
 
@@ -590,6 +570,6 @@ gint gap_proc_anim_apply(GimpRunMode run_mode, gint32 image_id, char *plugin_nam
   return(p_foreach_multilayer(run_mode,
                               image_id,
 			      plugin_name,
-			      l_apply_mode ));
+			      apply_mode ));
 
 }
