@@ -1,4 +1,4 @@
-/* $Header: /cvs/gnome/gimp-gap/libwavplayclient/wavplay.h,v 1.2 2003/09/13 00:36:20 neo Exp $
+/* $Header: /cvs/gnome/gimp-gap/libwavplayclient/wavplay.h,v 1.3 2005/08/21 21:05:25 jseidel Exp $
  * Warren W. Gay VE3WWG		Sun Feb 16 18:17:17 1997
  *
  * WAVPLAY OPTION SETTINGS:
@@ -55,7 +55,7 @@
  *
  */
 #ifndef _wavplay_h_
-#define _wavplay_h_ "$Id: wavplay.h,v 1.2 2003/09/13 00:36:20 neo Exp $"
+#define _wavplay_h_ "$Id: wavplay.h,v 1.3 2005/08/21 21:05:25 jseidel Exp $"
 
 #define WAVPLAY_VERSION		"1.4"
 
@@ -339,7 +339,7 @@ typedef struct {
 
 		/*
 		 * Message from server to client, to convey a fatal error that
-		 * has occured in the server.
+		 * has occurred in the server.
 		 */
 		struct	{
 			int	Errno;		/* Error code */
@@ -453,7 +453,7 @@ typedef struct {
 
 		/*
 		 * Message from server to client, to convey a NON-fatal error that
-		 * has occured in the server.
+		 * has occurred in the server.
 		 */
 		struct	{
 			int	Errno;		/* Error code */
